/*
 * This file was generated automatically by ExtUtils::ParseXS version 3.44 from the
 * contents of AUI.xs. Do not edit this file, edit AUI.xs instead.
 *
 *    ANY CHANGES MADE HERE WILL BE LOST!
 *
 */

/////////////////////////////////////////////////////////////////////////////
// Name:        ext/aui/AUI.xs
// Purpose:     XS for Wx::AUI
// Author:      Mattia Barbon
// Modified by:
// Created:     11/11/2006
// RCS-ID:      $Id: AUI.xs 3525 2014-10-28 01:36:38Z mdootson $
// Copyright:   (c) 2006, 2008-2010 Mattia Barbon
// Licence:     This program is free software; you can redistribute it and/or
//              modify it under the same terms as Perl itself
/////////////////////////////////////////////////////////////////////////////

#define PERL_NO_GET_CONTEXT

#include "cpp/wxapi.h"
#include "cpp/constants.h"
#include "cpp/overload.h"

#define wxNullBitmapPtr (wxBitmap*)&wxNullBitmap

#undef THIS

#include <wx/aui/framemanager.h>
#include <wx/aui/auibook.h>

// event macros
#define SEVT( NAME, ARGS )    wxPli_StdEvent( NAME, ARGS )
#define EVT( NAME, ARGS, ID ) wxPli_Event( NAME, ARGS, ID )

// !package: Wx::Event
// !tag:
// !parser: sub { $_[0] =~ m<^\s*S?EVT\(\s*(\w+)\s*\,> }

#if WXPERL_W_VERSION_LT( 2, 8, 0 )
#define wxEVT_AUI_PANE_BUTTON   wxEVT_AUI_PANEBUTTON
#define wxEVT_AUI_PANE_CLOSE    wxEVT_AUI_PANECLOSE
#define wxEVT_AUI_PANE_MAXIMIZE wxEVT_AUI_PANEMAXIMIZE
#define wxEVT_AUI_PANE_RESTORE  wxEVT_AUI_PANERESTORE
#endif

#if WXPERL_W_VERSION_GE( 2, 9, 5 )
#define wxEVT_COMMAND_AUINOTEBOOK_PAGE_CLOSE        wxEVT_AUINOTEBOOK_PAGE_CLOSE
#define wxEVT_COMMAND_AUINOTEBOOK_PAGE_CLOSED       wxEVT_AUINOTEBOOK_PAGE_CLOSED
#define wxEVT_COMMAND_AUINOTEBOOK_PAGE_CHANGED      wxEVT_AUINOTEBOOK_PAGE_CHANGED
#define wxEVT_COMMAND_AUINOTEBOOK_PAGE_CHANGING     wxEVT_AUINOTEBOOK_PAGE_CHANGING
#define wxEVT_COMMAND_AUINOTEBOOK_BUTTON            wxEVT_AUINOTEBOOK_BUTTON
#define wxEVT_COMMAND_AUINOTEBOOK_BEGIN_DRAG        wxEVT_AUINOTEBOOK_BEGIN_DRAG
#define wxEVT_COMMAND_AUINOTEBOOK_END_DRAG          wxEVT_AUINOTEBOOK_END_DRAG
#define wxEVT_COMMAND_AUINOTEBOOK_DRAG_MOTION       wxEVT_AUINOTEBOOK_DRAG_MOTION
#define wxEVT_COMMAND_AUINOTEBOOK_ALLOW_DND         wxEVT_AUINOTEBOOK_ALLOW_DND
#define wxEVT_COMMAND_AUINOTEBOOK_DRAG_DONE         wxEVT_AUINOTEBOOK_DRAG_DONE
#define wxEVT_COMMAND_AUINOTEBOOK_TAB_MIDDLE_DOWN   wxEVT_AUINOTEBOOK_TAB_MIDDLE_DOWN
#define wxEVT_COMMAND_AUINOTEBOOK_TAB_MIDDLE_UP     wxEVT_AUINOTEBOOK_TAB_MIDDLE_UP
#define wxEVT_COMMAND_AUINOTEBOOK_TAB_RIGHT_DOWN    wxEVT_AUINOTEBOOK_TAB_RIGHT_DOWN
#define wxEVT_COMMAND_AUINOTEBOOK_TAB_RIGHT_UP      wxEVT_AUINOTEBOOK_TAB_RIGHT_UP
#define wxEVT_COMMAND_AUINOTEBOOK_BG_DCLICK         wxEVT_AUINOTEBOOK_BG_DCLICK
#endif

static wxPliEventDescription evts[] =
{
    SEVT( EVT_AUI_PANE_BUTTON, 2 )
    SEVT( EVT_AUI_PANE_CLOSE, 2 )
    SEVT( EVT_AUI_PANE_MAXIMIZE, 2 )
    SEVT( EVT_AUI_PANE_RESTORE, 2 )
#if WXPERL_W_VERSION_GE( 2, 9, 4 )    
    SEVT( EVT_AUI_PANE_ACTIVATED, 2 )
#endif
    SEVT( EVT_AUI_RENDER, 2 )
    EVT( EVT_AUINOTEBOOK_PAGE_CLOSE, 3, wxEVT_COMMAND_AUINOTEBOOK_PAGE_CLOSE )
    EVT( EVT_AUINOTEBOOK_PAGE_CLOSED, 3, wxEVT_COMMAND_AUINOTEBOOK_PAGE_CLOSED )
    EVT( EVT_AUINOTEBOOK_PAGE_CHANGED, 3, wxEVT_COMMAND_AUINOTEBOOK_PAGE_CHANGED )
    EVT( EVT_AUINOTEBOOK_PAGE_CHANGING, 3, wxEVT_COMMAND_AUINOTEBOOK_PAGE_CHANGING )
    EVT( EVT_AUINOTEBOOK_BUTTON, 3, wxEVT_COMMAND_AUINOTEBOOK_BUTTON )
    EVT( EVT_AUINOTEBOOK_BEGIN_DRAG, 3, wxEVT_COMMAND_AUINOTEBOOK_BEGIN_DRAG )
    EVT( EVT_AUINOTEBOOK_END_DRAG, 3, wxEVT_COMMAND_AUINOTEBOOK_END_DRAG )
    EVT( EVT_AUINOTEBOOK_DRAG_MOTION, 3, wxEVT_COMMAND_AUINOTEBOOK_DRAG_MOTION )
    EVT( EVT_AUINOTEBOOK_ALLOW_DND, 3, wxEVT_COMMAND_AUINOTEBOOK_ALLOW_DND )
    EVT( EVT_AUINOTEBOOK_DRAG_DONE, 3, wxEVT_COMMAND_AUINOTEBOOK_DRAG_DONE )
    EVT( EVT_AUINOTEBOOK_TAB_MIDDLE_DOWN, 3, wxEVT_COMMAND_AUINOTEBOOK_TAB_MIDDLE_DOWN )
    EVT( EVT_AUINOTEBOOK_TAB_MIDDLE_UP, 3, wxEVT_COMMAND_AUINOTEBOOK_TAB_MIDDLE_UP )
    EVT( EVT_AUINOTEBOOK_TAB_RIGHT_DOWN, 3, wxEVT_COMMAND_AUINOTEBOOK_TAB_RIGHT_DOWN )
    EVT( EVT_AUINOTEBOOK_TAB_RIGHT_UP, 3, wxEVT_COMMAND_AUINOTEBOOK_TAB_RIGHT_UP )
    EVT( EVT_AUINOTEBOOK_BG_DCLICK, 3, wxEVT_COMMAND_AUINOTEBOOK_BG_DCLICK )
    { 0, 0, 0 }
};

#ifndef PERL_UNUSED_VAR
#  define PERL_UNUSED_VAR(var) if (0) var = var
#endif

#ifndef dVAR
#  define dVAR		dNOOP
#endif


/* This stuff is not part of the API! You have been warned. */
#ifndef PERL_VERSION_DECIMAL
#  define PERL_VERSION_DECIMAL(r,v,s) (r*1000000 + v*1000 + s)
#endif
#ifndef PERL_DECIMAL_VERSION
#  define PERL_DECIMAL_VERSION \
	  PERL_VERSION_DECIMAL(PERL_REVISION,PERL_VERSION,PERL_SUBVERSION)
#endif
#ifndef PERL_VERSION_GE
#  define PERL_VERSION_GE(r,v,s) \
	  (PERL_DECIMAL_VERSION >= PERL_VERSION_DECIMAL(r,v,s))
#endif
#ifndef PERL_VERSION_LE
#  define PERL_VERSION_LE(r,v,s) \
	  (PERL_DECIMAL_VERSION <= PERL_VERSION_DECIMAL(r,v,s))
#endif

/* XS_INTERNAL is the explicit static-linkage variant of the default
 * XS macro.
 *
 * XS_EXTERNAL is the same as XS_INTERNAL except it does not include
 * "STATIC", ie. it exports XSUB symbols. You probably don't want that
 * for anything but the BOOT XSUB.
 *
 * See XSUB.h in core!
 */


/* TODO: This might be compatible further back than 5.10.0. */
#if PERL_VERSION_GE(5, 10, 0) && PERL_VERSION_LE(5, 15, 1)
#  undef XS_EXTERNAL
#  undef XS_INTERNAL
#  if defined(__CYGWIN__) && defined(USE_DYNAMIC_LOADING)
#    define XS_EXTERNAL(name) __declspec(dllexport) XSPROTO(name)
#    define XS_INTERNAL(name) STATIC XSPROTO(name)
#  endif
#  if defined(__SYMBIAN32__)
#    define XS_EXTERNAL(name) EXPORT_C XSPROTO(name)
#    define XS_INTERNAL(name) EXPORT_C STATIC XSPROTO(name)
#  endif
#  ifndef XS_EXTERNAL
#    if defined(HASATTRIBUTE_UNUSED) && !defined(__cplusplus)
#      define XS_EXTERNAL(name) void name(pTHX_ CV* cv __attribute__unused__)
#      define XS_INTERNAL(name) STATIC void name(pTHX_ CV* cv __attribute__unused__)
#    else
#      ifdef __cplusplus
#        define XS_EXTERNAL(name) extern "C" XSPROTO(name)
#        define XS_INTERNAL(name) static XSPROTO(name)
#      else
#        define XS_EXTERNAL(name) XSPROTO(name)
#        define XS_INTERNAL(name) STATIC XSPROTO(name)
#      endif
#    endif
#  endif
#endif

/* perl >= 5.10.0 && perl <= 5.15.1 */


/* The XS_EXTERNAL macro is used for functions that must not be static
 * like the boot XSUB of a module. If perl didn't have an XS_EXTERNAL
 * macro defined, the best we can do is assume XS is the same.
 * Dito for XS_INTERNAL.
 */
#ifndef XS_EXTERNAL
#  define XS_EXTERNAL(name) XS(name)
#endif
#ifndef XS_INTERNAL
#  define XS_INTERNAL(name) XS(name)
#endif

/* Now, finally, after all this mess, we want an ExtUtils::ParseXS
 * internal macro that we're free to redefine for varying linkage due
 * to the EXPORT_XSUB_SYMBOLS XS keyword. This is internal, use
 * XS_EXTERNAL(name) or XS_INTERNAL(name) in your code if you need to!
 */

#undef XS_EUPXS
#if defined(PERL_EUPXS_ALWAYS_EXPORT)
#  define XS_EUPXS(name) XS_EXTERNAL(name)
#else
   /* default to internal */
#  define XS_EUPXS(name) XS_INTERNAL(name)
#endif

#ifndef PERL_ARGS_ASSERT_CROAK_XS_USAGE
#define PERL_ARGS_ASSERT_CROAK_XS_USAGE assert(cv); assert(params)

/* prototype to pass -Wmissing-prototypes */
STATIC void
S_croak_xs_usage(const CV *const cv, const char *const params);

STATIC void
S_croak_xs_usage(const CV *const cv, const char *const params)
{
    const GV *const gv = CvGV(cv);

    PERL_ARGS_ASSERT_CROAK_XS_USAGE;

    if (gv) {
        const char *const gvname = GvNAME(gv);
        const HV *const stash = GvSTASH(gv);
        const char *const hvname = stash ? HvNAME(stash) : NULL;

        if (hvname)
	    Perl_croak_nocontext("Usage: %s::%s(%s)", hvname, gvname, params);
        else
	    Perl_croak_nocontext("Usage: %s(%s)", gvname, params);
    } else {
        /* Pants. I don't think that it should be possible to get here. */
	Perl_croak_nocontext("Usage: CODE(0x%" UVxf ")(%s)", PTR2UV(cv), params);
    }
}
#undef  PERL_ARGS_ASSERT_CROAK_XS_USAGE

#define croak_xs_usage        S_croak_xs_usage

#endif

/* NOTE: the prototype of newXSproto() is different in versions of perls,
 * so we define a portable version of newXSproto()
 */
#ifdef newXS_flags
#define newXSproto_portable(name, c_impl, file, proto) newXS_flags(name, c_impl, file, proto, 0)
#else
#define newXSproto_portable(name, c_impl, file, proto) (PL_Sv=(SV*)newXS(name, c_impl, file), sv_setpv(PL_Sv, proto), (CV*)PL_Sv)
#endif /* !defined(newXS_flags) */

#if PERL_VERSION_LE(5, 21, 5)
#  define newXS_deffile(a,b) Perl_newXS(aTHX_ a,b,file)
#else
#  define newXS_deffile(a,b) Perl_newXS_deffile(aTHX_ a,b)
#endif


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/AuiManager.xsp' from 'AUI.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#include <wx/aui/framemanager.h>
#include <wx/aui/auibook.h>
#include "xspp/aui.h"
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__AuiManagerEvent_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManagerEvent_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "CLASS, type= wxEVT_NULL");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxAuiManagerEvent *	RETVAL;
	wxEventType	type;

	if (items < 2)
	    type = wxEVT_NULL;
	else {
	    type = (wxEventType)SvIV(ST(1))
;
	}
    try {
      RETVAL = new wxAuiManagerEvent( type );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiManagerEvent", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__AuiManagerEvent_SetButton); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManagerEvent_SetButton)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, b");
    {
	wxAuiManagerEvent *    THIS = (wxAuiManagerEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManagerEvent" )
;
	int	b = (int)SvIV(ST(1))
;
    try {
      THIS->SetButton( b );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AuiManagerEvent_GetPane); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManagerEvent_GetPane)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiManagerEvent *    THIS = (wxAuiManagerEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManagerEvent" )
;
	wxAuiPaneInfo *	RETVAL;
     RETVAL = THIS->GetPane(); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
     wxPli_object_set_deleteable( aTHX_ ST(0), false ); 
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiManagerEvent_GetButton); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManagerEvent_GetButton)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiManagerEvent *    THIS = (wxAuiManagerEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManagerEvent" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetButton();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiManagerEvent_Veto); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManagerEvent_Veto)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, veto= true");
    {
	wxAuiManagerEvent *    THIS = (wxAuiManagerEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManagerEvent" )
;
	bool	veto;

	if (items < 2)
	    veto = true;
	else {
	    veto = (bool)SvTRUE(ST(1))
;
	}
    try {
      THIS->Veto( veto );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AuiManagerEvent_GetVeto); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManagerEvent_GetVeto)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiManagerEvent *    THIS = (wxAuiManagerEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManagerEvent" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->GetVeto();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiManagerEvent_SetCanVeto); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManagerEvent_SetCanVeto)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, can_veto");
    {
	wxAuiManagerEvent *    THIS = (wxAuiManagerEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManagerEvent" )
;
	bool	can_veto = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetCanVeto( can_veto );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AuiManagerEvent_CanVeto); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManagerEvent_CanVeto)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiManagerEvent *    THIS = (wxAuiManagerEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManagerEvent" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->CanVeto();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__AuiManager_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManager_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "CLASS, managed_wnd= NULL, flags= wxAUI_MGR_DEFAULT");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxAuiManager *	RETVAL;
	wxWindow*	managed_wnd;
	unsigned int	flags;

	if (items < 2)
	    managed_wnd = NULL;
	else {
    managed_wnd = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	}

	if (items < 3)
	    flags = wxAUI_MGR_DEFAULT;
	else {
    flags = (unsigned int)SvUV( ST(2) )
;
	}
    try {
      RETVAL = new wxAuiManager( managed_wnd, flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiManager" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiManager", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__AuiManager_CLONE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManager_CLONE)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    wxPli_thread_sv_clone( aTHX_ CLASS, (wxPliCloneSV)wxPli_detach_object );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AuiManager_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManager_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiManager *    THIS = (wxAuiManager *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManager" )
;
      wxPli_thread_sv_unregister( aTHX_ "Wx::AuiManager", THIS, ST(0) );
                 delete THIS;
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AuiManager_UnInit); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManager_UnInit)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiManager *    THIS = (wxAuiManager *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManager" )
;
    try {
      THIS->UnInit();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AuiManager_SetFlags); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManager_SetFlags)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flags");
    {
	wxAuiManager *    THIS = (wxAuiManager *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManager" )
;
	unsigned int    flags = (unsigned int)SvUV( ST(1) )
;
    try {
      THIS->SetFlags( flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AuiManager_GetFlags); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManager_GetFlags)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiManager *    THIS = (wxAuiManager *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManager" )
;
	unsigned int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetFlags();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiManager_SetManagedWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManager_SetManagedWindow)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, managed_wnd");
    {
	wxAuiManager *    THIS = (wxAuiManager *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManager" )
;
	wxWindow*    managed_wnd = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
    try {
      THIS->SetManagedWindow( managed_wnd );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AuiManager_GetManagedWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManager_GetManagedWindow)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiManager *    THIS = (wxAuiManager *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManager" )
;
	wxWindow *	RETVAL;
    try {
      RETVAL = THIS->GetManagedWindow();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiManager_GetPaneWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManager_GetPaneWindow)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, window");
    {
	wxAuiManager *    THIS = (wxAuiManager *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManager" )
;
	wxAuiPaneInfo *	RETVAL;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
     RETVAL = &THIS->GetPane( window ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
     wxPli_object_set_deleteable( aTHX_ ST(0), false ); 
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiManager_GetPaneString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManager_GetPaneString)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxAuiManager *    THIS = (wxAuiManager *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManager" )
;
	wxAuiPaneInfo *	RETVAL;
	wxString	name;

    WXSTRING_INPUT( name, wxString, ST(1) )
;
     RETVAL = &THIS->GetPane( name ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
     wxPli_object_set_deleteable( aTHX_ ST(0), false ); 
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiManager_AddPaneDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManager_AddPaneDefault)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, window, pane_info");
    {
	wxAuiManager *    THIS = (wxAuiManager *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManager" )
;
	bool	RETVAL;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxAuiPaneInfo*    pane_info = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::AuiPaneInfo" )
;
    try {
      RETVAL = THIS->AddPane( window, *( pane_info ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiManager_AddPanePoint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManager_AddPanePoint)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, window, pane_info, drop_pos");
    {
	wxAuiManager *    THIS = (wxAuiManager *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManager" )
;
	bool	RETVAL;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxAuiPaneInfo*    pane_info = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::AuiPaneInfo" )
;
	wxPoint    drop_pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
    try {
      RETVAL = THIS->AddPane( window, *( pane_info ), drop_pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiManager_AddPaneDirection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManager_AddPaneDirection)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 4)
       croak_xs_usage(cv,  "THIS, window, direction= wxLEFT, caption= wxEmptyString");
    {
	wxAuiManager *    THIS = (wxAuiManager *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManager" )
;
	bool	RETVAL;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	int	direction;
	wxString	caption;

	if (items < 3)
	    direction = wxLEFT;
	else {
	    direction = (int)SvIV(ST(2))
;
	}

	if (items < 4)
	    caption = wxEmptyString;
	else {
    WXSTRING_INPUT( caption, wxString, ST(3) )
;
	}
    try {
      RETVAL = THIS->AddPane( window, direction, caption );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiManager_InsertPane); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManager_InsertPane)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 4)
       croak_xs_usage(cv,  "THIS, window, insert_location, insert_level= wxAUI_INSERT_PANE");
    {
	wxAuiManager *    THIS = (wxAuiManager *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManager" )
;
	bool	RETVAL;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxAuiPaneInfo*    insert_location = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::AuiPaneInfo" )
;
	int	insert_level;

	if (items < 4)
	    insert_level = wxAUI_INSERT_PANE;
	else {
	    insert_level = (int)SvIV(ST(3))
;
	}
    try {
      RETVAL = THIS->InsertPane( window, *( insert_location ), insert_level );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiManager_DetachPane); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManager_DetachPane)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, window");
    {
	wxAuiManager *    THIS = (wxAuiManager *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManager" )
;
	bool	RETVAL;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
    try {
      RETVAL = THIS->DetachPane( window );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiManager_ClosePane); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManager_ClosePane)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pane_info");
    {
	wxAuiManager *    THIS = (wxAuiManager *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManager" )
;
	wxAuiPaneInfo*    pane_info = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::AuiPaneInfo" )
;
    try {
      THIS->ClosePane( *( pane_info ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AuiManager_MaximizePane); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManager_MaximizePane)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pane_info");
    {
	wxAuiManager *    THIS = (wxAuiManager *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManager" )
;
	wxAuiPaneInfo*    pane_info = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::AuiPaneInfo" )
;
    try {
      THIS->MaximizePane( *( pane_info ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AuiManager_RestorePane); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManager_RestorePane)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pane_info");
    {
	wxAuiManager *    THIS = (wxAuiManager *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManager" )
;
	wxAuiPaneInfo*    pane_info = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::AuiPaneInfo" )
;
    try {
      THIS->RestorePane( *( pane_info ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AuiManager_RestoreMaximizedPane); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManager_RestoreMaximizedPane)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiManager *    THIS = (wxAuiManager *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManager" )
;
    try {
      THIS->RestoreMaximizedPane();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 8, 0 )
#define XSpp_7a9213ff_098217
#define XSubPPtmpAAAA 1


XS_EUPXS(XS_Wx__AuiManager_SetDockSizeConstraint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManager_SetDockSizeConstraint)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, width_pct, height_pct");
    {
	wxAuiManager *    THIS = (wxAuiManager *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManager" )
;
	double	width_pct = (double)SvNV(ST(1))
;
	double	height_pct = (double)SvNV(ST(2))
;
    try {
      THIS->SetDockSizeConstraint( width_pct, height_pct );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__AuiManager_SavePaneInfo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManager_SavePaneInfo)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pane");
    {
	wxAuiManager *    THIS = (wxAuiManager *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManager" )
;
	wxString	RETVAL;
	wxAuiPaneInfo*    pane = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::AuiPaneInfo" )
;
    try {
      RETVAL = THIS->SavePaneInfo( *( pane ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiManager_LoadPaneInfo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManager_LoadPaneInfo)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, pane_part, pane");
    {
	wxAuiManager *    THIS = (wxAuiManager *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManager" )
;
	wxString	pane_part;
	wxAuiPaneInfo*    pane = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::AuiPaneInfo" )
;

    WXSTRING_INPUT( pane_part, wxString, ST(1) )
;
    try {
      THIS->LoadPaneInfo( pane_part, *( pane ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AuiManager_SavePerspective); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManager_SavePerspective)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiManager *    THIS = (wxAuiManager *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManager" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->SavePerspective();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiManager_LoadPerspective); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManager_LoadPerspective)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, perspective, update= true");
    {
	wxAuiManager *    THIS = (wxAuiManager *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManager" )
;
	bool	RETVAL;
	wxString	perspective;
	bool	update;

    WXSTRING_INPUT( perspective, wxString, ST(1) )
;

	if (items < 3)
	    update = true;
	else {
	    update = (bool)SvTRUE(ST(2))
;
	}
    try {
      RETVAL = THIS->LoadPerspective( perspective, update );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiManager_Update); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManager_Update)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiManager *    THIS = (wxAuiManager *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManager" )
;
    try {
      THIS->Update();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AuiManager_ShowHint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManager_ShowHint)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, rect");
    {
	wxAuiManager *    THIS = (wxAuiManager *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManager" )
;
	wxRect*    rect = (wxRect *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Rect" )
;
    try {
      THIS->ShowHint( *( rect ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AuiManager_HideHint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManager_HideHint)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiManager *    THIS = (wxAuiManager *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManager" )
;
    try {
      THIS->HideHint();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AuiManager_GetPane); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManager_GetPane)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxAuiManager *    THIS = (wxAuiManager *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManager" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wwin, GetPaneWindow )
        MATCH_REDISP( wxPliOvl_s, GetPaneString )
    END_OVERLOAD( "Wx::AuiManager::GetPane" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__AuiManager_GetAllPanes); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManager_GetAllPanes)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxAuiManager *    THIS = (wxAuiManager *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManager" )
;
    const wxAuiPaneInfoArray& panes = THIS->GetAllPanes();
    PUTBACK;
    wxPli_non_objarray_push( aTHX_ panes, "Wx::AuiPaneInfo" );
    SPAGAIN;
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__AuiManager_AddPane); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiManager_AddPane)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxAuiManager *    THIS = (wxAuiManager *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiManager" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP_COUNT( wxPliOvl_wwin_wapi, AddPaneDefault, 2 )
        MATCH_REDISP( wxPliOvl_wwin_wapi_wpoi, AddPanePoint )
        MATCH_REDISP( wxPliOvl_wwin_n_s, AddPaneDirection )
    END_OVERLOAD( "Wx::AuiManager::AddPane" )
	PUTBACK;
	return;
    }
}


/* INCLUDE: Returning to 'AUI.xs' from '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/AuiManager.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/AuiPaneInfo.xsp' from 'AUI.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#include <wx/aui/framemanager.h>
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__AuiPaneInfo_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_new)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxAuiPaneInfo *	RETVAL;
    try {
      RETVAL = new wxAuiPaneInfo();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__AuiPaneInfo_CLONE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_CLONE)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    wxPli_thread_sv_clone( aTHX_ CLASS, (wxPliCloneSV)wxPli_detach_object );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AuiPaneInfo_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
      wxPli_thread_sv_unregister( aTHX_ "Wx::AuiPaneInfo", THIS, ST(0) );
                 if( wxPli_object_is_deleteable( aTHX_ ST(0) ) )
                     delete THIS;
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AuiPaneInfo_SafeSet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_SafeSet)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, source");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo*    source = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::AuiPaneInfo" )
;
    try {
      THIS->SafeSet( *( source ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AuiPaneInfo_IsOk); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_IsOk)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsOk();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_IsFixed); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_IsFixed)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsFixed();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_IsResizable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_IsResizable)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsResizable();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_IsShown); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_IsShown)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsShown();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_IsFloating); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_IsFloating)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsFloating();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_IsDocked); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_IsDocked)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsDocked();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_IsToolbar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_IsToolbar)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsToolbar();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_IsTopDockable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_IsTopDockable)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsTopDockable();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_IsBottomDockable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_IsBottomDockable)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsBottomDockable();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_IsLeftDockable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_IsLeftDockable)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsLeftDockable();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_IsRightDockable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_IsRightDockable)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsRightDockable();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_IsFloatable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_IsFloatable)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsFloatable();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_IsMovable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_IsMovable)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsMovable();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_IsDestroyOnClose); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_IsDestroyOnClose)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsDestroyOnClose();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_IsMaximized); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_IsMaximized)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsMaximized();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_HasCaption); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_HasCaption)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasCaption();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_HasGripper); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_HasGripper)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasGripper();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_HasBorder); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_HasBorder)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasBorder();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_HasCloseButton); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_HasCloseButton)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasCloseButton();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_HasMaximizeButton); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_HasMaximizeButton)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasMaximizeButton();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_HasMinimizeButton); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_HasMinimizeButton)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasMinimizeButton();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_HasPinButton); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_HasPinButton)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasPinButton();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_HasGripperTop); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_HasGripperTop)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasGripperTop();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_Window); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_Window)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, w");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	wxWindow*    w = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->Window( w ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_Name); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_Name)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	wxString	n;

    WXSTRING_INPUT( n, wxString, ST(1) )
;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->Name( n ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_Caption); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_Caption)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, c");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	wxString	c;

    WXSTRING_INPUT( c, wxString, ST(1) )
;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->Caption( c ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_Left); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_Left)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->Left() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_Right); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_Right)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->Right() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_Top); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_Top)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->Top() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_Bottom); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_Bottom)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->Bottom() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_Center); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_Center)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->Center() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_Centre); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_Centre)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->Centre() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_Direction); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_Direction)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, direction");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	int	direction = (int)SvIV(ST(1))
;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->Direction( direction ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_Layer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_Layer)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, layer");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	int	layer = (int)SvIV(ST(1))
;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->Layer( layer ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_Row); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_Row)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, row");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	int	row = (int)SvIV(ST(1))
;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->Row( row ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_Position); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_Position)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	int	pos = (int)SvIV(ST(1))
;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->Position( pos ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_435f7608_060645
#define XSubPPtmpAAAB 1


XS_EUPXS(XS_Wx__AuiPaneInfo_DockFixed); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_DockFixed)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, b= true");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	bool	b;

	if (items < 2)
	    b = true;
	else {
	    b = (bool)SvTRUE(ST(1))
;
	}
    try {
      RETVAL = new wxAuiPaneInfo( THIS->DockFixed( b ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__AuiPaneInfo_BestSizeSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_BestSizeSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, size");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	wxSize    size = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->BestSize( size ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_BestSizeWH); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_BestSizeWH)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, x, y");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	int	x = (int)SvIV(ST(1))
;
	int	y = (int)SvIV(ST(2))
;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->BestSize( x, y ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_BestSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_BestSize)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wsiz, BestSizeSize )
        MATCH_REDISP( wxPliOvl_n_n, BestSizeWH )
    END_OVERLOAD( Wx::AuiPaneInfo::BestSize )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__AuiPaneInfo_MaxSizeSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_MaxSizeSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, size");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	wxSize    size = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->MaxSize( size ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_MaxSizeWH); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_MaxSizeWH)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, x, y");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	int	x = (int)SvIV(ST(1))
;
	int	y = (int)SvIV(ST(2))
;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->MaxSize( x, y ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_MaxSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_MaxSize)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wsiz, MaxSizeSize )
        MATCH_REDISP( wxPliOvl_n_n, MaxSizeWH )
    END_OVERLOAD( Wx::AuiPaneInfo::MaxSize )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__AuiPaneInfo_MinSizeSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_MinSizeSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, size");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	wxSize    size = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->MinSize( size ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_MinSizeWH); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_MinSizeWH)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, x, y");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	int	x = (int)SvIV(ST(1))
;
	int	y = (int)SvIV(ST(2))
;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->MinSize( x, y ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_MinSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_MinSize)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wsiz, MinSizeSize )
        MATCH_REDISP( wxPliOvl_n_n, MinSizeWH )
    END_OVERLOAD( Wx::AuiPaneInfo::MinSize )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__AuiPaneInfo_FloatingPositionPoint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_FloatingPositionPoint)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	wxPoint    pos = wxPli_sv_2_wxpoint( aTHX_ ST(1) )
;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->FloatingPosition( pos ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_FloatingPositionXY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_FloatingPositionXY)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, x, y");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	int	x = (int)SvIV(ST(1))
;
	int	y = (int)SvIV(ST(2))
;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->FloatingPosition( x, y ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_FloatingPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_FloatingPosition)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wsiz, FloatingPositionPoint )
        MATCH_REDISP( wxPliOvl_n_n, FloatingPositionXY )
    END_OVERLOAD( Wx::AuiPaneInfo::FloatingPosition )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__AuiPaneInfo_FloatingSizeSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_FloatingSizeSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, size");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	wxSize    size = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->FloatingSize( size ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_FloatingSizeWH); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_FloatingSizeWH)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, x, y");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	int	x = (int)SvIV(ST(1))
;
	int	y = (int)SvIV(ST(2))
;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->FloatingSize( x, y ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_FloatingSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_FloatingSize)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wsiz, FloatingSizeSize )
        MATCH_REDISP( wxPliOvl_n_n, FloatingSizeWH )
    END_OVERLOAD( Wx::AuiPaneInfo::FloatingSize )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__AuiPaneInfo_Fixed); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_Fixed)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->Fixed() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_Resizable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_Resizable)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, resizable= true");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	bool	resizable;

	if (items < 2)
	    resizable = true;
	else {
	    resizable = (bool)SvTRUE(ST(1))
;
	}
    try {
      RETVAL = new wxAuiPaneInfo( THIS->Resizable( resizable ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_Dock); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_Dock)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->Dock() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_Float); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_Float)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->Float() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_Hide); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_Hide)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->Hide() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_Show); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_Show)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, show= true");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	bool	show;

	if (items < 2)
	    show = true;
	else {
	    show = (bool)SvTRUE(ST(1))
;
	}
    try {
      RETVAL = new wxAuiPaneInfo( THIS->Show( show ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_CaptionVisible); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_CaptionVisible)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, visible= true");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	bool	visible;

	if (items < 2)
	    visible = true;
	else {
	    visible = (bool)SvTRUE(ST(1))
;
	}
    try {
      RETVAL = new wxAuiPaneInfo( THIS->CaptionVisible( visible ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_Maximize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_Maximize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->Maximize() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_Restore); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_Restore)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->Restore() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_PaneBorder); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_PaneBorder)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, visible= true");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	bool	visible;

	if (items < 2)
	    visible = true;
	else {
	    visible = (bool)SvTRUE(ST(1))
;
	}
    try {
      RETVAL = new wxAuiPaneInfo( THIS->PaneBorder( visible ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_Gripper); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_Gripper)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, visible= true");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	bool	visible;

	if (items < 2)
	    visible = true;
	else {
	    visible = (bool)SvTRUE(ST(1))
;
	}
    try {
      RETVAL = new wxAuiPaneInfo( THIS->Gripper( visible ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_GripperTop); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_GripperTop)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, attop= true");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	bool	attop;

	if (items < 2)
	    attop = true;
	else {
	    attop = (bool)SvTRUE(ST(1))
;
	}
    try {
      RETVAL = new wxAuiPaneInfo( THIS->GripperTop( attop ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_CloseButton); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_CloseButton)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, visible= true");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	bool	visible;

	if (items < 2)
	    visible = true;
	else {
	    visible = (bool)SvTRUE(ST(1))
;
	}
    try {
      RETVAL = new wxAuiPaneInfo( THIS->CloseButton( visible ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_MaximizeButton); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_MaximizeButton)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, visible= true");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	bool	visible;

	if (items < 2)
	    visible = true;
	else {
	    visible = (bool)SvTRUE(ST(1))
;
	}
    try {
      RETVAL = new wxAuiPaneInfo( THIS->MaximizeButton( visible ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_MinimizeButton); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_MinimizeButton)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, visible= true");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	bool	visible;

	if (items < 2)
	    visible = true;
	else {
	    visible = (bool)SvTRUE(ST(1))
;
	}
    try {
      RETVAL = new wxAuiPaneInfo( THIS->MinimizeButton( visible ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_PinButton); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_PinButton)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, visible= true");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	bool	visible;

	if (items < 2)
	    visible = true;
	else {
	    visible = (bool)SvTRUE(ST(1))
;
	}
    try {
      RETVAL = new wxAuiPaneInfo( THIS->PinButton( visible ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_DestroyOnClose); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_DestroyOnClose)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, b= true");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	bool	b;

	if (items < 2)
	    b = true;
	else {
	    b = (bool)SvTRUE(ST(1))
;
	}
    try {
      RETVAL = new wxAuiPaneInfo( THIS->DestroyOnClose( b ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_TopDockable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_TopDockable)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, b= true");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	bool	b;

	if (items < 2)
	    b = true;
	else {
	    b = (bool)SvTRUE(ST(1))
;
	}
    try {
      RETVAL = new wxAuiPaneInfo( THIS->TopDockable( b ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_BottomDockable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_BottomDockable)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, b= true");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	bool	b;

	if (items < 2)
	    b = true;
	else {
	    b = (bool)SvTRUE(ST(1))
;
	}
    try {
      RETVAL = new wxAuiPaneInfo( THIS->BottomDockable( b ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_LeftDockable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_LeftDockable)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, b= true");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	bool	b;

	if (items < 2)
	    b = true;
	else {
	    b = (bool)SvTRUE(ST(1))
;
	}
    try {
      RETVAL = new wxAuiPaneInfo( THIS->LeftDockable( b ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_RightDockable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_RightDockable)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, b= true");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	bool	b;

	if (items < 2)
	    b = true;
	else {
	    b = (bool)SvTRUE(ST(1))
;
	}
    try {
      RETVAL = new wxAuiPaneInfo( THIS->RightDockable( b ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_Floatable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_Floatable)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, b= true");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	bool	b;

	if (items < 2)
	    b = true;
	else {
	    b = (bool)SvTRUE(ST(1))
;
	}
    try {
      RETVAL = new wxAuiPaneInfo( THIS->Floatable( b ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_Movable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_Movable)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, b= true");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	bool	b;

	if (items < 2)
	    b = true;
	else {
	    b = (bool)SvTRUE(ST(1))
;
	}
    try {
      RETVAL = new wxAuiPaneInfo( THIS->Movable( b ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_LT( 2, 8, 0 )
#define XSpp_435f7608_004629
#define XSubPPtmpAAAC 1


XS_EUPXS(XS_Wx__AuiPaneInfo_SaveHidden); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_SaveHidden)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->SaveHidden() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_RestoreHidden); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_RestoreHidden)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->RestoreHidden() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__AuiPaneInfo_Dockable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_Dockable)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, b= true");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	bool	b;

	if (items < 2)
	    b = true;
	else {
	    b = (bool)SvTRUE(ST(1))
;
	}
    try {
      RETVAL = new wxAuiPaneInfo( THIS->Dockable( b ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_DefaultPane); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_DefaultPane)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->DefaultPane() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_CentrePane); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_CentrePane)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->CentrePane() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_CenterPane); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_CenterPane)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->CenterPane() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_ToolbarPane); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_ToolbarPane)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->ToolbarPane() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_SetFlag); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_SetFlag)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, flag, option_state");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	wxAuiPaneInfo *	RETVAL;
	unsigned int    flag = (unsigned int)SvUV( ST(1) )
;
	bool	option_state = (bool)SvTRUE(ST(2))
;
    try {
      RETVAL = new wxAuiPaneInfo( THIS->SetFlag( flag, option_state ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiPaneInfo" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiPaneInfo", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiPaneInfo_HasFlag); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiPaneInfo_HasFlag)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flag");
    {
	wxAuiPaneInfo *    THIS = (wxAuiPaneInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiPaneInfo" )
;
	bool	RETVAL;
	unsigned int    flag = (unsigned int)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->HasFlag( flag );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to 'AUI.xs' from '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/AuiPaneInfo.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/AuiNotebook.xsp' from 'AUI.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#include <wx/aui/auibook.h>
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__AuiNotebookEvent_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebookEvent_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "CLASS, command_type= wxEVT_NULL, win_id= 0");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxAuiNotebookEvent *	RETVAL;
	wxEventType	command_type;
	int	win_id;

	if (items < 2)
	    command_type = wxEVT_NULL;
	else {
	    command_type = (wxEventType)SvIV(ST(1))
;
	}

	if (items < 3)
	    win_id = 0;
	else {
	    win_id = (int)SvIV(ST(2))
;
	}
    try {
      RETVAL = new wxAuiNotebookEvent( command_type, win_id );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiNotebookEvent", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__AuiNotebookEvent_SetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebookEvent_SetSelection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, s");
    {
	wxAuiNotebookEvent *    THIS = (wxAuiNotebookEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiNotebookEvent" )
;
	int	s = (int)SvIV(ST(1))
;
    try {
      THIS->SetSelection( s );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AuiNotebookEvent_GetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebookEvent_GetSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiNotebookEvent *    THIS = (wxAuiNotebookEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiNotebookEvent" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiNotebookEvent_SetOldSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebookEvent_SetOldSelection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, s");
    {
	wxAuiNotebookEvent *    THIS = (wxAuiNotebookEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiNotebookEvent" )
;
	int	s = (int)SvIV(ST(1))
;
    try {
      THIS->SetOldSelection( s );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AuiNotebookEvent_GetOldSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebookEvent_GetOldSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiNotebookEvent *    THIS = (wxAuiNotebookEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiNotebookEvent" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetOldSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiNotebookEvent_SetDragSource); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebookEvent_SetDragSource)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, s");
    {
	wxAuiNotebookEvent *    THIS = (wxAuiNotebookEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiNotebookEvent" )
;
	wxAuiNotebook*    s = (wxAuiNotebook *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::AuiNotebook" )
;
    try {
      THIS->SetDragSource( s );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AuiNotebookEvent_GetDragSource); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebookEvent_GetDragSource)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiNotebookEvent *    THIS = (wxAuiNotebookEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiNotebookEvent" )
;
	wxAuiNotebook *	RETVAL;
    try {
      RETVAL = THIS->GetDragSource();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__AuiNotebook_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebook_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxAuiNotebook *	RETVAL;
     RETVAL = new wxAuiNotebook();
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__AuiNotebook_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebook_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 6)
       croak_xs_usage(cv,  "CLASS, parent, id= wxID_ANY, pos= wxDefaultPosition, size= wxDefaultSize, style= wxAUI_NB_DEFAULT_STYLE");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxAuiNotebook *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = wxAUI_NB_DEFAULT_STYLE;
	else {
	    style = (long)SvIV(ST(5))
;
	}
     RETVAL = new wxAuiNotebook( parent, id,
                                            pos, size, style );
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__AuiNotebook_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebook_new)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "CLASS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::AuiNotebook::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__AuiNotebook_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebook_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 6)
       croak_xs_usage(cv,  "THIS, parent, id= wxID_ANY, pos= wxDefaultPosition, size= wxDefaultSize, style= 0");
    {
	wxAuiNotebook *    THIS = (wxAuiNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiNotebook" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = 0;
	else {
	    style = (long)SvIV(ST(5))
;
	}
    try {
      RETVAL = THIS->Create( parent, id, pos, size, style );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiNotebook_AddPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebook_AddPage)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 5)
       croak_xs_usage(cv,  "THIS, page, caption, select= false, bitmap= wxNullBitmapPtr");
    {
	wxAuiNotebook *    THIS = (wxAuiNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiNotebook" )
;
	bool	RETVAL;
	wxWindow*    page = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxString	caption;
	bool	select;
	wxBitmap*	bitmap;

    WXSTRING_INPUT( caption, wxString, ST(2) )
;

	if (items < 4)
	    select = false;
	else {
	    select = (bool)SvTRUE(ST(3))
;
	}

	if (items < 5)
	    bitmap = wxNullBitmapPtr;
	else {
    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(4), "Wx::Bitmap" )
;
	}
    try {
      RETVAL = THIS->AddPage( page, caption, select, *( bitmap ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiNotebook_InsertPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebook_InsertPage)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 6)
       croak_xs_usage(cv,  "THIS, page_idx, page, caption, select= false, bitmap= wxNullBitmapPtr");
    {
	wxAuiNotebook *    THIS = (wxAuiNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiNotebook" )
;
	bool	RETVAL;
	size_t    page_idx = (size_t)SvUV( ST(1) )
;
	wxWindow*    page = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Window" )
;
	wxString	caption;
	bool	select;
	wxBitmap*	bitmap;

    WXSTRING_INPUT( caption, wxString, ST(3) )
;

	if (items < 5)
	    select = false;
	else {
	    select = (bool)SvTRUE(ST(4))
;
	}

	if (items < 6)
	    bitmap = wxNullBitmapPtr;
	else {
    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(5), "Wx::Bitmap" )
;
	}
    try {
      RETVAL = THIS->InsertPage( page_idx, page, caption, select, *( bitmap ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiNotebook_DeletePage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebook_DeletePage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, page");
    {
	wxAuiNotebook *    THIS = (wxAuiNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiNotebook" )
;
	bool	RETVAL;
	size_t    page = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->DeletePage( page );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiNotebook_RemovePage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebook_RemovePage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, page");
    {
	wxAuiNotebook *    THIS = (wxAuiNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiNotebook" )
;
	bool	RETVAL;
	size_t    page = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->RemovePage( page );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiNotebook_SetWindowStyleFlag); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebook_SetWindowStyleFlag)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, style");
    {
	wxAuiNotebook *    THIS = (wxAuiNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiNotebook" )
;
	long	style = (long)SvIV(ST(1))
;
    try {
      THIS->SetWindowStyleFlag( style );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AuiNotebook_SetPageText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebook_SetPageText)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, page, text");
    {
	wxAuiNotebook *    THIS = (wxAuiNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiNotebook" )
;
	bool	RETVAL;
	size_t    page = (size_t)SvUV( ST(1) )
;
	wxString	text;

    WXSTRING_INPUT( text, wxString, ST(2) )
;
    try {
      RETVAL = THIS->SetPageText( page, text );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 8, 0 )
#define XSpp_332e01f0_086096
#define XSubPPtmpAAAD 1


XS_EUPXS(XS_Wx__AuiNotebook_GetPageText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebook_GetPageText)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, page");
    {
	wxAuiNotebook *    THIS = (wxAuiNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiNotebook" )
;
	wxString	RETVAL;
	size_t    page = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->GetPageText( page );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiNotebook_SetPageBitmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebook_SetPageBitmap)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, page, bitmap");
    {
	wxAuiNotebook *    THIS = (wxAuiNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiNotebook" )
;
	bool	RETVAL;
	size_t    page = (size_t)SvUV( ST(1) )
;
	wxBitmap*    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Bitmap" )
;
    try {
      RETVAL = THIS->SetPageBitmap( page, *( bitmap ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiNotebook_GetPageBitmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebook_GetPageBitmap)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, index");
    {
	wxAuiNotebook *    THIS = (wxAuiNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiNotebook" )
;
	wxBitmap *	RETVAL;
	size_t    index = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = new wxBitmap( THIS->GetPageBitmap( index ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Bitmap", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__AuiNotebook_SetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebook_SetSelection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, new_page");
    {
	wxAuiNotebook *    THIS = (wxAuiNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiNotebook" )
;
	size_t	RETVAL;
	dXSTARG;
	size_t    new_page = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->SetSelection( new_page );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiNotebook_GetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebook_GetSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiNotebook *    THIS = (wxAuiNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiNotebook" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiNotebook_GetPageCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebook_GetPageCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiNotebook *    THIS = (wxAuiNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiNotebook" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetPageCount();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiNotebook_GetPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebook_GetPage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, page_idx");
    {
	wxAuiNotebook *    THIS = (wxAuiNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiNotebook" )
;
	wxWindow *	RETVAL;
	size_t    page_idx = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->GetPage( page_idx );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 8, 0 )
#define XSpp_332e01f0_018361
#define XSubPPtmpAAAE 1


XS_EUPXS(XS_Wx__AuiNotebook_GetPageIndex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebook_GetPageIndex)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, page_wnd");
    {
	wxAuiNotebook *    THIS = (wxAuiNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiNotebook" )
;
	int	RETVAL;
	dXSTARG;
	wxWindow*    page_wnd = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
    try {
      RETVAL = THIS->GetPageIndex( page_wnd );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_GE( 2, 8, 0 )
#define XSpp_332e01f0_046884
#define XSubPPtmpAAAF 1


XS_EUPXS(XS_Wx__AuiNotebook_Split); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebook_Split)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, page, direction");
    {
	wxAuiNotebook *    THIS = (wxAuiNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiNotebook" )
;
	size_t    page = (size_t)SvUV( ST(1) )
;
	int	direction = (int)SvIV(ST(2))
;
    try {
      THIS->Split( page, direction );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif
#if WXPERL_W_VERSION_GE( 2, 9, 0 ) || WXPERL_W_VERSION_GE( 2, 8, 1 ) 
#define XSpp_332e01f0_048453
#define XSubPPtmpAAAG 1


XS_EUPXS(XS_Wx__AuiNotebook_GetAuiManager); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebook_GetAuiManager)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiNotebook *    THIS = (wxAuiNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiNotebook" )
;
	const wxAuiManager *	RETVAL;
     RETVAL = &THIS->GetAuiManager(); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AuiManager" );
    wxPli_thread_sv_register( aTHX_ "Wx::AuiManager", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_GE( 2, 9, 0 ) || WXPERL_W_VERSION_GE( 2, 8, 5 ) 
#define XSpp_332e01f0_088823
#define XSubPPtmpAAAH 1


XS_EUPXS(XS_Wx__AuiNotebook_AdvanceSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebook_AdvanceSelection)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, advance= true");
    {
	wxAuiNotebook *    THIS = (wxAuiNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiNotebook" )
;
	bool	advance;

	if (items < 2)
	    advance = true;
	else {
	    advance = (bool)SvTRUE(ST(1))
;
	}
    try {
      THIS->AdvanceSelection( advance );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AuiNotebook_GetHeightForPageHeight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebook_GetHeightForPageHeight)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pageHeight");
    {
	wxAuiNotebook *    THIS = (wxAuiNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiNotebook" )
;
	int	RETVAL;
	dXSTARG;
	int	pageHeight = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->GetHeightForPageHeight( pageHeight );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiNotebook_GetTabCtrlHeight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebook_GetTabCtrlHeight)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiNotebook *    THIS = (wxAuiNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiNotebook" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetTabCtrlHeight();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AuiNotebook_SetNormalFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebook_SetNormalFont)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, font");
    {
	wxAuiNotebook *    THIS = (wxAuiNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiNotebook" )
;
	wxFont*    font = (wxFont *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Font" )
;
    try {
      THIS->SetNormalFont( *( font ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AuiNotebook_SetSelectedFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebook_SetSelectedFont)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, font");
    {
	wxAuiNotebook *    THIS = (wxAuiNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiNotebook" )
;
	wxFont*    font = (wxFont *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Font" )
;
    try {
      THIS->SetSelectedFont( *( font ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AuiNotebook_SetMeasuringFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebook_SetMeasuringFont)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, font");
    {
	wxAuiNotebook *    THIS = (wxAuiNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiNotebook" )
;
	wxFont*    font = (wxFont *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Font" )
;
    try {
      THIS->SetMeasuringFont( *( font ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AuiNotebook_SetTabCtrlHeight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebook_SetTabCtrlHeight)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, height");
    {
	wxAuiNotebook *    THIS = (wxAuiNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiNotebook" )
;
	int	height = (int)SvIV(ST(1))
;
    try {
      THIS->SetTabCtrlHeight( height );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AuiNotebook_ShowWindowMenu); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebook_ShowWindowMenu)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAuiNotebook *    THIS = (wxAuiNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiNotebook" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->ShowWindowMenu();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__AuiNotebook_SetUniformBitmapSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AuiNotebook_SetUniformBitmapSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, size");
    {
	wxAuiNotebook *    THIS = (wxAuiNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AuiNotebook" )
;
	wxSize    size = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
    try {
      THIS->SetUniformBitmapSize( size );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


/* INCLUDE: Returning to 'AUI.xs' from '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/AuiNotebook.xsp' */


XS_EUPXS(XS_Wx__AUI_SetEvents); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AUI_SetEvents)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
    wxPli_set_events( evts );
    }
    XSRETURN_EMPTY;
}

#include "cpp/ovl_const.cpp"
#if defined(__WXMSW__)
#undef XS
#define XS( name ) WXXS( name )
#endif
#ifdef __cplusplus
extern "C"
#endif
XS_EXTERNAL(boot_Wx__AUI); /* prototype to pass -Wmissing-prototypes */
XS_EXTERNAL(boot_Wx__AUI)
{
#if PERL_VERSION_LE(5, 21, 5)
    dVAR; dXSARGS;
#else
    dVAR; dXSBOOTARGSXSAPIVERCHK;
#endif
#if PERL_VERSION_LE(5, 8, 999) /* PERL_VERSION_LT is 5.33+ */
    char* file = __FILE__;
#else
    const char* file = __FILE__;
#endif

    PERL_UNUSED_VAR(file);

    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
#if PERL_VERSION_LE(5, 21, 5)
    XS_VERSION_BOOTCHECK;
#  ifdef XS_APIVERSION_BOOTCHECK
    XS_APIVERSION_BOOTCHECK;
#  endif
#endif

        newXS_deffile("Wx::AuiManagerEvent::new", XS_Wx__AuiManagerEvent_new);
        newXS_deffile("Wx::AuiManagerEvent::SetButton", XS_Wx__AuiManagerEvent_SetButton);
        newXS_deffile("Wx::AuiManagerEvent::GetPane", XS_Wx__AuiManagerEvent_GetPane);
        newXS_deffile("Wx::AuiManagerEvent::GetButton", XS_Wx__AuiManagerEvent_GetButton);
        newXS_deffile("Wx::AuiManagerEvent::Veto", XS_Wx__AuiManagerEvent_Veto);
        newXS_deffile("Wx::AuiManagerEvent::GetVeto", XS_Wx__AuiManagerEvent_GetVeto);
        newXS_deffile("Wx::AuiManagerEvent::SetCanVeto", XS_Wx__AuiManagerEvent_SetCanVeto);
        newXS_deffile("Wx::AuiManagerEvent::CanVeto", XS_Wx__AuiManagerEvent_CanVeto);
        newXS_deffile("Wx::AuiManager::new", XS_Wx__AuiManager_new);
        newXS_deffile("Wx::AuiManager::CLONE", XS_Wx__AuiManager_CLONE);
        newXS_deffile("Wx::AuiManager::DESTROY", XS_Wx__AuiManager_DESTROY);
        newXS_deffile("Wx::AuiManager::UnInit", XS_Wx__AuiManager_UnInit);
        newXS_deffile("Wx::AuiManager::SetFlags", XS_Wx__AuiManager_SetFlags);
        newXS_deffile("Wx::AuiManager::GetFlags", XS_Wx__AuiManager_GetFlags);
        newXS_deffile("Wx::AuiManager::SetManagedWindow", XS_Wx__AuiManager_SetManagedWindow);
        newXS_deffile("Wx::AuiManager::GetManagedWindow", XS_Wx__AuiManager_GetManagedWindow);
        newXS_deffile("Wx::AuiManager::GetPaneWindow", XS_Wx__AuiManager_GetPaneWindow);
        newXS_deffile("Wx::AuiManager::GetPaneString", XS_Wx__AuiManager_GetPaneString);
        newXS_deffile("Wx::AuiManager::AddPaneDefault", XS_Wx__AuiManager_AddPaneDefault);
        newXS_deffile("Wx::AuiManager::AddPanePoint", XS_Wx__AuiManager_AddPanePoint);
        newXS_deffile("Wx::AuiManager::AddPaneDirection", XS_Wx__AuiManager_AddPaneDirection);
        newXS_deffile("Wx::AuiManager::InsertPane", XS_Wx__AuiManager_InsertPane);
        newXS_deffile("Wx::AuiManager::DetachPane", XS_Wx__AuiManager_DetachPane);
        newXS_deffile("Wx::AuiManager::ClosePane", XS_Wx__AuiManager_ClosePane);
        newXS_deffile("Wx::AuiManager::MaximizePane", XS_Wx__AuiManager_MaximizePane);
        newXS_deffile("Wx::AuiManager::RestorePane", XS_Wx__AuiManager_RestorePane);
        newXS_deffile("Wx::AuiManager::RestoreMaximizedPane", XS_Wx__AuiManager_RestoreMaximizedPane);
#if XSubPPtmpAAAA
        newXS_deffile("Wx::AuiManager::SetDockSizeConstraint", XS_Wx__AuiManager_SetDockSizeConstraint);
#endif
        newXS_deffile("Wx::AuiManager::SavePaneInfo", XS_Wx__AuiManager_SavePaneInfo);
        newXS_deffile("Wx::AuiManager::LoadPaneInfo", XS_Wx__AuiManager_LoadPaneInfo);
        newXS_deffile("Wx::AuiManager::SavePerspective", XS_Wx__AuiManager_SavePerspective);
        newXS_deffile("Wx::AuiManager::LoadPerspective", XS_Wx__AuiManager_LoadPerspective);
        newXS_deffile("Wx::AuiManager::Update", XS_Wx__AuiManager_Update);
        newXS_deffile("Wx::AuiManager::ShowHint", XS_Wx__AuiManager_ShowHint);
        newXS_deffile("Wx::AuiManager::HideHint", XS_Wx__AuiManager_HideHint);
        newXS_deffile("Wx::AuiManager::GetPane", XS_Wx__AuiManager_GetPane);
        newXS_deffile("Wx::AuiManager::GetAllPanes", XS_Wx__AuiManager_GetAllPanes);
        newXS_deffile("Wx::AuiManager::AddPane", XS_Wx__AuiManager_AddPane);
        newXS_deffile("Wx::AuiPaneInfo::new", XS_Wx__AuiPaneInfo_new);
        newXS_deffile("Wx::AuiPaneInfo::CLONE", XS_Wx__AuiPaneInfo_CLONE);
        newXS_deffile("Wx::AuiPaneInfo::DESTROY", XS_Wx__AuiPaneInfo_DESTROY);
        newXS_deffile("Wx::AuiPaneInfo::SafeSet", XS_Wx__AuiPaneInfo_SafeSet);
        newXS_deffile("Wx::AuiPaneInfo::IsOk", XS_Wx__AuiPaneInfo_IsOk);
        newXS_deffile("Wx::AuiPaneInfo::IsFixed", XS_Wx__AuiPaneInfo_IsFixed);
        newXS_deffile("Wx::AuiPaneInfo::IsResizable", XS_Wx__AuiPaneInfo_IsResizable);
        newXS_deffile("Wx::AuiPaneInfo::IsShown", XS_Wx__AuiPaneInfo_IsShown);
        newXS_deffile("Wx::AuiPaneInfo::IsFloating", XS_Wx__AuiPaneInfo_IsFloating);
        newXS_deffile("Wx::AuiPaneInfo::IsDocked", XS_Wx__AuiPaneInfo_IsDocked);
        newXS_deffile("Wx::AuiPaneInfo::IsToolbar", XS_Wx__AuiPaneInfo_IsToolbar);
        newXS_deffile("Wx::AuiPaneInfo::IsTopDockable", XS_Wx__AuiPaneInfo_IsTopDockable);
        newXS_deffile("Wx::AuiPaneInfo::IsBottomDockable", XS_Wx__AuiPaneInfo_IsBottomDockable);
        newXS_deffile("Wx::AuiPaneInfo::IsLeftDockable", XS_Wx__AuiPaneInfo_IsLeftDockable);
        newXS_deffile("Wx::AuiPaneInfo::IsRightDockable", XS_Wx__AuiPaneInfo_IsRightDockable);
        newXS_deffile("Wx::AuiPaneInfo::IsFloatable", XS_Wx__AuiPaneInfo_IsFloatable);
        newXS_deffile("Wx::AuiPaneInfo::IsMovable", XS_Wx__AuiPaneInfo_IsMovable);
        newXS_deffile("Wx::AuiPaneInfo::IsDestroyOnClose", XS_Wx__AuiPaneInfo_IsDestroyOnClose);
        newXS_deffile("Wx::AuiPaneInfo::IsMaximized", XS_Wx__AuiPaneInfo_IsMaximized);
        newXS_deffile("Wx::AuiPaneInfo::HasCaption", XS_Wx__AuiPaneInfo_HasCaption);
        newXS_deffile("Wx::AuiPaneInfo::HasGripper", XS_Wx__AuiPaneInfo_HasGripper);
        newXS_deffile("Wx::AuiPaneInfo::HasBorder", XS_Wx__AuiPaneInfo_HasBorder);
        newXS_deffile("Wx::AuiPaneInfo::HasCloseButton", XS_Wx__AuiPaneInfo_HasCloseButton);
        newXS_deffile("Wx::AuiPaneInfo::HasMaximizeButton", XS_Wx__AuiPaneInfo_HasMaximizeButton);
        newXS_deffile("Wx::AuiPaneInfo::HasMinimizeButton", XS_Wx__AuiPaneInfo_HasMinimizeButton);
        newXS_deffile("Wx::AuiPaneInfo::HasPinButton", XS_Wx__AuiPaneInfo_HasPinButton);
        newXS_deffile("Wx::AuiPaneInfo::HasGripperTop", XS_Wx__AuiPaneInfo_HasGripperTop);
        newXS_deffile("Wx::AuiPaneInfo::Window", XS_Wx__AuiPaneInfo_Window);
        newXS_deffile("Wx::AuiPaneInfo::Name", XS_Wx__AuiPaneInfo_Name);
        newXS_deffile("Wx::AuiPaneInfo::Caption", XS_Wx__AuiPaneInfo_Caption);
        newXS_deffile("Wx::AuiPaneInfo::Left", XS_Wx__AuiPaneInfo_Left);
        newXS_deffile("Wx::AuiPaneInfo::Right", XS_Wx__AuiPaneInfo_Right);
        newXS_deffile("Wx::AuiPaneInfo::Top", XS_Wx__AuiPaneInfo_Top);
        newXS_deffile("Wx::AuiPaneInfo::Bottom", XS_Wx__AuiPaneInfo_Bottom);
        newXS_deffile("Wx::AuiPaneInfo::Center", XS_Wx__AuiPaneInfo_Center);
        newXS_deffile("Wx::AuiPaneInfo::Centre", XS_Wx__AuiPaneInfo_Centre);
        newXS_deffile("Wx::AuiPaneInfo::Direction", XS_Wx__AuiPaneInfo_Direction);
        newXS_deffile("Wx::AuiPaneInfo::Layer", XS_Wx__AuiPaneInfo_Layer);
        newXS_deffile("Wx::AuiPaneInfo::Row", XS_Wx__AuiPaneInfo_Row);
        newXS_deffile("Wx::AuiPaneInfo::Position", XS_Wx__AuiPaneInfo_Position);
#if XSubPPtmpAAAB
        newXS_deffile("Wx::AuiPaneInfo::DockFixed", XS_Wx__AuiPaneInfo_DockFixed);
#endif
        newXS_deffile("Wx::AuiPaneInfo::BestSizeSize", XS_Wx__AuiPaneInfo_BestSizeSize);
        newXS_deffile("Wx::AuiPaneInfo::BestSizeWH", XS_Wx__AuiPaneInfo_BestSizeWH);
        newXS_deffile("Wx::AuiPaneInfo::BestSize", XS_Wx__AuiPaneInfo_BestSize);
        newXS_deffile("Wx::AuiPaneInfo::MaxSizeSize", XS_Wx__AuiPaneInfo_MaxSizeSize);
        newXS_deffile("Wx::AuiPaneInfo::MaxSizeWH", XS_Wx__AuiPaneInfo_MaxSizeWH);
        newXS_deffile("Wx::AuiPaneInfo::MaxSize", XS_Wx__AuiPaneInfo_MaxSize);
        newXS_deffile("Wx::AuiPaneInfo::MinSizeSize", XS_Wx__AuiPaneInfo_MinSizeSize);
        newXS_deffile("Wx::AuiPaneInfo::MinSizeWH", XS_Wx__AuiPaneInfo_MinSizeWH);
        newXS_deffile("Wx::AuiPaneInfo::MinSize", XS_Wx__AuiPaneInfo_MinSize);
        newXS_deffile("Wx::AuiPaneInfo::FloatingPositionPoint", XS_Wx__AuiPaneInfo_FloatingPositionPoint);
        newXS_deffile("Wx::AuiPaneInfo::FloatingPositionXY", XS_Wx__AuiPaneInfo_FloatingPositionXY);
        newXS_deffile("Wx::AuiPaneInfo::FloatingPosition", XS_Wx__AuiPaneInfo_FloatingPosition);
        newXS_deffile("Wx::AuiPaneInfo::FloatingSizeSize", XS_Wx__AuiPaneInfo_FloatingSizeSize);
        newXS_deffile("Wx::AuiPaneInfo::FloatingSizeWH", XS_Wx__AuiPaneInfo_FloatingSizeWH);
        newXS_deffile("Wx::AuiPaneInfo::FloatingSize", XS_Wx__AuiPaneInfo_FloatingSize);
        newXS_deffile("Wx::AuiPaneInfo::Fixed", XS_Wx__AuiPaneInfo_Fixed);
        newXS_deffile("Wx::AuiPaneInfo::Resizable", XS_Wx__AuiPaneInfo_Resizable);
        newXS_deffile("Wx::AuiPaneInfo::Dock", XS_Wx__AuiPaneInfo_Dock);
        newXS_deffile("Wx::AuiPaneInfo::Float", XS_Wx__AuiPaneInfo_Float);
        newXS_deffile("Wx::AuiPaneInfo::Hide", XS_Wx__AuiPaneInfo_Hide);
        newXS_deffile("Wx::AuiPaneInfo::Show", XS_Wx__AuiPaneInfo_Show);
        newXS_deffile("Wx::AuiPaneInfo::CaptionVisible", XS_Wx__AuiPaneInfo_CaptionVisible);
        newXS_deffile("Wx::AuiPaneInfo::Maximize", XS_Wx__AuiPaneInfo_Maximize);
        newXS_deffile("Wx::AuiPaneInfo::Restore", XS_Wx__AuiPaneInfo_Restore);
        newXS_deffile("Wx::AuiPaneInfo::PaneBorder", XS_Wx__AuiPaneInfo_PaneBorder);
        newXS_deffile("Wx::AuiPaneInfo::Gripper", XS_Wx__AuiPaneInfo_Gripper);
        newXS_deffile("Wx::AuiPaneInfo::GripperTop", XS_Wx__AuiPaneInfo_GripperTop);
        newXS_deffile("Wx::AuiPaneInfo::CloseButton", XS_Wx__AuiPaneInfo_CloseButton);
        newXS_deffile("Wx::AuiPaneInfo::MaximizeButton", XS_Wx__AuiPaneInfo_MaximizeButton);
        newXS_deffile("Wx::AuiPaneInfo::MinimizeButton", XS_Wx__AuiPaneInfo_MinimizeButton);
        newXS_deffile("Wx::AuiPaneInfo::PinButton", XS_Wx__AuiPaneInfo_PinButton);
        newXS_deffile("Wx::AuiPaneInfo::DestroyOnClose", XS_Wx__AuiPaneInfo_DestroyOnClose);
        newXS_deffile("Wx::AuiPaneInfo::TopDockable", XS_Wx__AuiPaneInfo_TopDockable);
        newXS_deffile("Wx::AuiPaneInfo::BottomDockable", XS_Wx__AuiPaneInfo_BottomDockable);
        newXS_deffile("Wx::AuiPaneInfo::LeftDockable", XS_Wx__AuiPaneInfo_LeftDockable);
        newXS_deffile("Wx::AuiPaneInfo::RightDockable", XS_Wx__AuiPaneInfo_RightDockable);
        newXS_deffile("Wx::AuiPaneInfo::Floatable", XS_Wx__AuiPaneInfo_Floatable);
        newXS_deffile("Wx::AuiPaneInfo::Movable", XS_Wx__AuiPaneInfo_Movable);
#if XSubPPtmpAAAC
        newXS_deffile("Wx::AuiPaneInfo::SaveHidden", XS_Wx__AuiPaneInfo_SaveHidden);
        newXS_deffile("Wx::AuiPaneInfo::RestoreHidden", XS_Wx__AuiPaneInfo_RestoreHidden);
#endif
        newXS_deffile("Wx::AuiPaneInfo::Dockable", XS_Wx__AuiPaneInfo_Dockable);
        newXS_deffile("Wx::AuiPaneInfo::DefaultPane", XS_Wx__AuiPaneInfo_DefaultPane);
        newXS_deffile("Wx::AuiPaneInfo::CentrePane", XS_Wx__AuiPaneInfo_CentrePane);
        newXS_deffile("Wx::AuiPaneInfo::CenterPane", XS_Wx__AuiPaneInfo_CenterPane);
        newXS_deffile("Wx::AuiPaneInfo::ToolbarPane", XS_Wx__AuiPaneInfo_ToolbarPane);
        newXS_deffile("Wx::AuiPaneInfo::SetFlag", XS_Wx__AuiPaneInfo_SetFlag);
        newXS_deffile("Wx::AuiPaneInfo::HasFlag", XS_Wx__AuiPaneInfo_HasFlag);
        newXS_deffile("Wx::AuiNotebookEvent::new", XS_Wx__AuiNotebookEvent_new);
        newXS_deffile("Wx::AuiNotebookEvent::SetSelection", XS_Wx__AuiNotebookEvent_SetSelection);
        newXS_deffile("Wx::AuiNotebookEvent::GetSelection", XS_Wx__AuiNotebookEvent_GetSelection);
        newXS_deffile("Wx::AuiNotebookEvent::SetOldSelection", XS_Wx__AuiNotebookEvent_SetOldSelection);
        newXS_deffile("Wx::AuiNotebookEvent::GetOldSelection", XS_Wx__AuiNotebookEvent_GetOldSelection);
        newXS_deffile("Wx::AuiNotebookEvent::SetDragSource", XS_Wx__AuiNotebookEvent_SetDragSource);
        newXS_deffile("Wx::AuiNotebookEvent::GetDragSource", XS_Wx__AuiNotebookEvent_GetDragSource);
        newXS_deffile("Wx::AuiNotebook::newDefault", XS_Wx__AuiNotebook_newDefault);
        newXS_deffile("Wx::AuiNotebook::newFull", XS_Wx__AuiNotebook_newFull);
        newXS_deffile("Wx::AuiNotebook::new", XS_Wx__AuiNotebook_new);
        newXS_deffile("Wx::AuiNotebook::Create", XS_Wx__AuiNotebook_Create);
        newXS_deffile("Wx::AuiNotebook::AddPage", XS_Wx__AuiNotebook_AddPage);
        newXS_deffile("Wx::AuiNotebook::InsertPage", XS_Wx__AuiNotebook_InsertPage);
        newXS_deffile("Wx::AuiNotebook::DeletePage", XS_Wx__AuiNotebook_DeletePage);
        newXS_deffile("Wx::AuiNotebook::RemovePage", XS_Wx__AuiNotebook_RemovePage);
        newXS_deffile("Wx::AuiNotebook::SetWindowStyleFlag", XS_Wx__AuiNotebook_SetWindowStyleFlag);
        newXS_deffile("Wx::AuiNotebook::SetPageText", XS_Wx__AuiNotebook_SetPageText);
#if XSubPPtmpAAAD
        newXS_deffile("Wx::AuiNotebook::GetPageText", XS_Wx__AuiNotebook_GetPageText);
        newXS_deffile("Wx::AuiNotebook::SetPageBitmap", XS_Wx__AuiNotebook_SetPageBitmap);
        newXS_deffile("Wx::AuiNotebook::GetPageBitmap", XS_Wx__AuiNotebook_GetPageBitmap);
#endif
        newXS_deffile("Wx::AuiNotebook::SetSelection", XS_Wx__AuiNotebook_SetSelection);
        newXS_deffile("Wx::AuiNotebook::GetSelection", XS_Wx__AuiNotebook_GetSelection);
        newXS_deffile("Wx::AuiNotebook::GetPageCount", XS_Wx__AuiNotebook_GetPageCount);
        newXS_deffile("Wx::AuiNotebook::GetPage", XS_Wx__AuiNotebook_GetPage);
#if XSubPPtmpAAAE
        newXS_deffile("Wx::AuiNotebook::GetPageIndex", XS_Wx__AuiNotebook_GetPageIndex);
#endif
#if XSubPPtmpAAAF
        newXS_deffile("Wx::AuiNotebook::Split", XS_Wx__AuiNotebook_Split);
#endif
#if XSubPPtmpAAAG
        newXS_deffile("Wx::AuiNotebook::GetAuiManager", XS_Wx__AuiNotebook_GetAuiManager);
#endif
#if XSubPPtmpAAAH
        newXS_deffile("Wx::AuiNotebook::AdvanceSelection", XS_Wx__AuiNotebook_AdvanceSelection);
        newXS_deffile("Wx::AuiNotebook::GetHeightForPageHeight", XS_Wx__AuiNotebook_GetHeightForPageHeight);
        newXS_deffile("Wx::AuiNotebook::GetTabCtrlHeight", XS_Wx__AuiNotebook_GetTabCtrlHeight);
        newXS_deffile("Wx::AuiNotebook::SetNormalFont", XS_Wx__AuiNotebook_SetNormalFont);
        newXS_deffile("Wx::AuiNotebook::SetSelectedFont", XS_Wx__AuiNotebook_SetSelectedFont);
        newXS_deffile("Wx::AuiNotebook::SetMeasuringFont", XS_Wx__AuiNotebook_SetMeasuringFont);
        newXS_deffile("Wx::AuiNotebook::SetTabCtrlHeight", XS_Wx__AuiNotebook_SetTabCtrlHeight);
        newXS_deffile("Wx::AuiNotebook::ShowWindowMenu", XS_Wx__AuiNotebook_ShowWindowMenu);
#endif
        newXS_deffile("Wx::AuiNotebook::SetUniformBitmapSize", XS_Wx__AuiNotebook_SetUniformBitmapSize);
        newXS_deffile("Wx::AUI::SetEvents", XS_Wx__AUI_SetEvents);

    /* Initialisation Section */

  INIT_PLI_HELPERS( wx_pli_helpers );

#if XSubPPtmpAAAA
#endif
#if XSubPPtmpAAAB
#endif
#if XSubPPtmpAAAC
#endif
#if XSubPPtmpAAAD
#endif
#if XSubPPtmpAAAE
#endif
#if XSubPPtmpAAAF
#endif
#if XSubPPtmpAAAG
#endif
#if XSubPPtmpAAAH
#endif

    /* End of Initialisation Section */

#if PERL_VERSION_LE(5, 21, 5)
#  if PERL_VERSION_GE(5, 9, 0)
    if (PL_unitcheckav)
        call_list(PL_scopestack_ix, PL_unitcheckav);
#  endif
    XSRETURN_YES;
#else
    Perl_xs_boot_epilog(aTHX_ ax);
#endif
}

